Checks that the input data frame has the appropriate format and data for simulations with medfate.
Value
An (invisible) list with two data frames, one with missing values in strict parameters and the other with plant names whose parameters (observed or imputed) do not conform to physiological rules.
Details
The function can perform two kinds of parameter check.
A formal check is always performed with the following rules:
The input is a data frame.
All parameter names defined in
SpParamsDefinitionshould be listed as columns.Strict parameters should not contain missing values. Strict parameters are defined as such in
SpParamsDefinition.
If check_consistency = TRUE, the function also performs the following consistency checks for the parameter values of each species:
Rule 1. Stem hydraulic vulnerability is not larger than leaf hydraulic vulnerability (i.e. VCstem_P50 not less negative than VCleaf_P50) (Bartlett et al. 2016).
Rule 2. Stem hydraulic vulnerability is not larger than root hydraulic vulnerability (i.e. VCstem_P50 not less negative than VCroot_P50).
Rule 3. Stem hydraulic vulnerability is not larger than the water potential at 50% stomatal conductance (i.e. VCstem_P50 not less negative than Gs_P50).
Rule 4. Stem hydraulic vulnerability curve is consistent (VCstem_P88 < VCstem_P50 < VCstem_P12).
Rule 5. Leaf hydraulic vulnerability curve is consistent (VCleaf_P88 < VCleaf_P50 < VCleaf_P12).
Rule 6. Root hydraulic vulnerability curve is consistent (VCroot_P88 < VCroot_P50 < VCroot_P12).
Rule 7. Maximum (stomatal) conductance is larger than minimum (cuticular) stomatal conductance (Gswmax > Gswmin).
Rule 8. Leaf wilting point is less than 50% of stomatal closure (Ptlp(function of LeafPI0 and LeafEPS) < Gs_P50) (Bartlett et al. 2016).
Parameter consistency is conducted including imputation of missing values, according to medfate inbuilt parameter estimation.